import { className, mergeData } from '../../core/utils'
import Panel from '../panel/panel'
import TableRow from './table-row'

const renderWrapper = (h, ctx, tag, name, children) => {
  return h(tag, {
    class: className(ctx, name)
  }, children)
}

const renderRow = (h, ctx, slot, props) => {
  return h(TableRow, { props }, ctx.slots()[slot])
}

const renderHeader = (h, ctx) => {
  return ctx.props.showHeader ?
    renderWrapper(h, ctx, 'header', 'table-header', [
      renderRow(h, ctx, 'header', { divider: false })
    ]) : null
}

const renderFooter = (h, ctx) => {
  return ctx.props.showFooter ?
    renderWrapper(h, ctx, 'footer', 'table-footer', [
      renderRow(h, ctx, 'footer')
    ]) : null
}

const renderBody = (h, ctx) => {
  return ctx.props.showBody
    ? renderWrapper(h, ctx, 'div', 'table-body', ctx.slots().default)
    : null
}

export default {
  functional: true,
  inject: [
    'fela',
    'croudClassName'
  ],
  props: {
    tag: {
      type: String,
      default: 'div'
    },
    dim: {
      type: Boolean
    },
    showHeader: {
      type: Boolean,
      default: true
    },
    showFooter: {
      type: Boolean,
      default: true
    },
    showBody: {
      type: Boolean,
      default: true
    }
  },
  render(h, ctx) {
    const { tag, dim } = ctx.props
    return h(Panel, mergeData(ctx, {
      class: className(ctx, 'table'),
      props: { tag, dim, space: false }
    }), [
      renderHeader(h, ctx),
      renderBody(h, ctx),
      renderFooter(h, ctx)
    ])
  }
}
